import { createVNode as _createVNode, resolveDirective as _resolveDirective } from "vue";
// Styles
import "./VAvatar.sass"; // Composables

import { makeRoundedProps, useRounded } from "../../composables/rounded.mjs";
import { makeSizeProps, useSize } from "../../composables/size.mjs";
import { makeTagProps } from "../../composables/tag.mjs";
import { useBackgroundColor } from "../../composables/color.mjs"; // Utilities

import { defineComponent, toRef } from 'vue';
import { makeProps } from "../../util/index.mjs";
export default defineComponent({
  name: 'VAvatar',
  props: makeProps({
    color: String,
    left: Boolean,
    right: Boolean,
    ...makeRoundedProps(),
    ...makeSizeProps(),
    ...makeTagProps()
  }),

  setup(props, {
    slots
  }) {
    const {
      backgroundColorClasses,
      backgroundColorStyles
    } = useBackgroundColor(toRef(props, 'color'));
    const {
      roundedClasses
    } = useRounded(props, 'v-avatar');
    const {
      sizeClasses,
      sizeStyles
    } = useSize(props, 'v-avatar');
    return () => _createVNode(props.tag, {
      "class": ['v-avatar', {
        'v-avatar--left': props.left,
        'v-avatar--right': props.right
      }, backgroundColorClasses.value, roundedClasses.value, sizeClasses.value],
      "style": [backgroundColorStyles.value, sizeStyles.value]
    }, { ...slots,
      _: 1
    }, 8, ["class", "style"]);
  }

});
//# sourceMappingURL=VAvatar.mjs.map